pub struct WrappedFn {
pub function: ItemFn,
pub pre_code: Option<TokenStream>,
pub post_code: Option<TokenStream>,
pub wrapper_ident: Ident,
pub result_ident: Ident,
}Expand description
Function that can have code inserted before and after the rest of the function executes.
Can be constructed with syn::parse() and other variations of parsing from the syn crate.
Example:
let mut function = parse_macro_input!(token_stream as WrappedFn);Code that runs before the function can be set using the set_pre_code() method.
Example:
function.set_pre_code(quote!{ println!("Hi at the start :)"); });Code that runs after the function can be set using the set_post_code() method.
Example:
function.set_post_code(quote!{ println!("Hi at the end :)"); });Fields
function: ItemFnsyn::ItemFn that contains all of the data of the original function, including the code inside, the function signature, any attributes, etc.
pre_code: Option<TokenStream>Contains code that gets run before the rest of the function.
post_code: Option<TokenStream>Contains code that gets run after the rest of the function.
wrapper_ident: IdentIdentifier token for the closure that wraps all of the original code from the wrapped function. wrapper by default.
result_ident: IdentIdentifier token for the variable that holds the return value of the wrapped function. result by default.
Implementations
Sourceimpl WrappedFn
impl WrappedFn
Sourcepub fn set_pre_code(&mut self, pre_code: TokenStream)
pub fn set_pre_code(&mut self, pre_code: TokenStream)
Sets the code that gets run before the rest of the function executes.
Sourcepub fn set_post_code(&mut self, post_code: TokenStream)
pub fn set_post_code(&mut self, post_code: TokenStream)
Sets the code that gets run after the rest of the function executes.
Sourcepub fn remove_pre_code(&mut self)
pub fn remove_pre_code(&mut self)
Removes any code that was going to be added before the rest of the function.
Sourcepub fn remove_post_code(&mut self)
pub fn remove_post_code(&mut self)
Removes any code that was going to be added after the rest of the function.
Sourcepub fn set_wrapper_ident(&mut self, ident: &str)
pub fn set_wrapper_ident(&mut self, ident: &str)
Changes the identifier for the closure that wraps the code of the original function (wrapper by default).
Sourcepub fn set_result_ident(&mut self, ident: &str)
pub fn set_result_ident(&mut self, ident: &str)
Changes the identifier for the variable that holds the value that the function returns (result by default).